@@ -117,11 +117,20 @@ class ConnectWiseBoard(TimeStampedModel):
                 closed_status=True,
             )
         except BoardStatus.DoesNotExist:
-            # There's nothing called "Closed".
-            # filter...first returns None if nothing is found.
+            # Using first this time because there could be many and we
+            # still don't know which one it could be, or just get None.
             closed_status = self.board_statuses.filter(
+                name__iregex=r'^[[:punct:]]*Closed[[:punct:]]*$',
                 closed_status=True,
             ).first()
+
+            if not closed_status:
+                # There's nothing called "Closed", or "Closed" surrounded by
+                # special charaters.
+                # filter...first returns None if nothing is found again.
+                closed_status = self.board_statuses.filter(
+                    closed_status=True,
+                ).first()
         return closed_status
 
 
@@ -953,6 +962,24 @@ class ProjectPhase(TimeStampedModel):
         return self.description
 
 
+class ProjectTeamMember(TimeStampedModel):
+    start_date = models.DateTimeField(blank=True, null=True)
+    end_date = models.DateTimeField(blank=True, null=True)
+
+    project = models.ForeignKey(
+        'Project', null=True, on_delete=models.SET_NULL
+    )
+    member = models.ForeignKey(
+        'Member', null=True, on_delete=models.SET_NULL
+    )
+    work_role = models.ForeignKey(
+        'WorkRole', null=True, on_delete=models.SET_NULL
+    )
+
+    def __str__(self):
+        return '{}/{}'.format(self.id, self.member)
+
+
 class AvailableProjectManager(models.Manager):
     """
     Return only projects whose status closed field is False.
@@ -1004,6 +1031,9 @@ class Project(TimeStampedModel):
         null=True,
         on_delete=models.SET_NULL
     )
+    team_members = models.ManyToManyField(
+        'Member', through='ProjectTeamMember',
+    )
 
     objects = models.Manager()
     available_objects = AvailableProjectManager()
